import React from "react";
import type { Service } from 'ahooks/lib/useRequest/src/types.d';
import type { Moment } from 'moment';
export interface FilterProps extends FilterContentProps {
    /** 额外的筛选条件 */
    addFields?: FieldsType;
    /** 卡片类名 */
    overlayClassName?: string;
    /** 卡片样式 */
    overlayStyle?: string;
    /** 重置事件 */
    onReset?: () => void;
    /** 展开行为， 可选'hover' | 'focus' | 'click' | 'contextMenu' */
    trigger?: string | string[];
    /** 筛选按钮文案，默认“筛选” */
    btnText?: string;
    /** 自定义筛选按钮 */
    btnRender?: React.ReactNode;
    /** 条件选择后的回调，默认失焦触发 */
    filterOk?: (filterParmas: FilterParamsType[] | [], formValues: FieldsType) => void;
    /** 筛选值数据 */
    items?: ItemType[];
    /** 🍄默认筛选条件字段（暂未实现） */
    searchFields?: FieldsType;
    /** 筛选结果数量 */
    total?: number;
    /** 单位 */
    unit?: string;
    /** 设置组件高度 */
    setHeight?: (height: number) => void;
    /** 筛选右侧自定义组件 */
    filterNode?: React.ReactNode;
    /** 筛选左侧侧自定义组件 */
    filterLeftNode?: React.ReactNode;
    /** 是否展示筛选结果及筛选条件tag */
    showSelectedTag?: boolean;
}
export declare type FieldType = 'selection' | 'string' | 'number' | 'date' | 'address' | 'org' | 'emp' | 'object';
/** 最终搜索入参类型 */
export interface FilterParamsType {
    /** 字段ID */
    fieldId: string;
    /** 日期范围选择 */
    range?: {
        from: string;
        to: string;
    };
    /** 选项值 */
    selections: string[] | [];
    /** 输入框value值 */
    value: string;
    /** 比较符号 */
    express?: string;
}
export interface ItemType {
    fieldId: string;
    fieldType: FieldType | string;
    fieldName: string;
    selection?: {
        label: string;
        value: string;
    }[] | null;
    type?: string;
    /** 是否在下拉选项中展示出来 */
    showOption?: boolean;
    multiSelect?: boolean | null;
    placeholder?: string | string[];
    config?: {
        action: Service<unknown, any[]>;
        params?: {};
    };
    [key: string]: any;
}
export declare type ItemsMapType = Map<string, Omit<ItemType, 'selection' | 'showOption' | 'placeholder'>>;
export interface FilterContentProps {
    /** 主标题文案 */
    filterTitle?: React.ReactNode;
    /** 主标题副文案 */
    filterSecondTitle?: React.ReactNode;
}
/** 从Form表单中获取到的数据类型 */
export declare type FieldsType = {
    fieldName?: string;
    fieldId: string;
    express?: string;
    value: [Moment, Moment] | string | string[] | number | {
        label: string;
        value: string;
    }[];
    onTagClose?: () => void;
    closeable?: boolean;
    fieldType?: FieldType;
}[];
